@@ -18,7 +18,6 @@
 /* #undef WITH_GPROF */
 /* #undef WITH_SSE2 */
 /* #undef WITH_NEON */
-/* #undef WITH_IPP */
 #define WITH_CUPS
 #define WITH_JPEG
 /* #undef WITH_WIN8 */
@@ -74,7 +73,7 @@
 #define CHANNEL_CLIPRDR_SERVER
 #define CHANNEL_DISP
 #define CHANNEL_DISP_CLIENT
-/* #undef CHANNEL_DISP_SERVER */
+#define CHANNEL_DISP_SERVER
 #define CHANNEL_DRDYNVC
 #define CHANNEL_DRDYNVC_CLIENT
 #define CHANNEL_DRDYNVC_SERVER
@@ -104,7 +103,7 @@
 /* #undef CHANNEL_PRINTER_SERVER */
 #define CHANNEL_RAIL
 #define CHANNEL_RAIL_CLIENT
-/* #undef CHANNEL_RAIL_SERVER */
+#define CHANNEL_RAIL_SERVER
 /* #undef CHANNEL_RDPAPPLIST */
 /* #undef CHANNEL_RDPAPPLIST_CLIENT */
 /* #undef CHANNEL_RDPAPPLIST_SERVER */
@@ -116,10 +115,10 @@
 #define CHANNEL_RDPECAM_SERVER
 #define CHANNEL_RDPEI
 #define CHANNEL_RDPEI_CLIENT
-/* #undef CHANNEL_RDPEI_SERVER */
+#define CHANNEL_RDPEI_SERVER
 #define CHANNEL_RDPGFX
 #define CHANNEL_RDPGFX_CLIENT
-/* #undef CHANNEL_RDPGFX_SERVER */
+#define CHANNEL_RDPGFX_SERVER
 #define CHANNEL_RDPEMSC
 /* #undef CHANNEL_RDPEMSC_CLIENT */
 #define CHANNEL_RDPEMSC_SERVER
